==> v1.0.0.1000.tar.gz: athena-opt-demo/demo-athenaopt_backend/develop/src/main/java/com/digiwin/athena/app/service/order/SalesOrderDetailCreateEAIService.java <==
package com.digiwin.athena.app.service.order;

import com.alibaba.fastjson.TypeReference;
import com.digiwin.app.service.DWEAIResult;
import com.digiwin.athena.app.infra.dto.order.SalesOrderDetailDTO;
import com.digiwin.athena.app.infra.entity.SalesOrderDetailEntity;
import com.digiwin.athena.app.infra.service.SalesOrderDetailService;
import com.digiwin.athena.opt.common.eai.EAIRequest;
import com.digiwin.athena.opt.common.eai.EAIUtil;
import com.digiwin.athena.opt.common.eai.service.AbsEAIService;
import com.digiwin.athena.opt.common.generator.SnowflakeWorker;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author CR-7
 * create: 2023-04-27 15:35
 * Description:
 */
@Log4j2
@Service
public class SalesOrderDetailCreateEAIService extends AbsEAIService {

    @Resource
    SalesOrderDetailService salesOrderDetailService;


    @Override
    public String getServiceName() {
        return SalesOrderDetailUtil.DEMO_SO_ITEM_INFO_CREATE;
    }

    @Override
    public DWEAIResult execute(Map<String, String> headers, String messageBody) throws Exception {
        // 入参反序列化
        EAIRequest request = new EAIRequest(messageBody);
        List<SalesOrderDetailDTO> salesOrderDetailDTOList = request.getObject("sales_order_detail", new TypeReference<List<SalesOrderDetailDTO>>(){});

        List<SalesOrderDetailEntity> salesOrderDetailEntityList = salesOrderDetailDTOList.stream().map(assemble->{
            SalesOrderDetailEntity salesOrderDetailEntity = new SalesOrderDetailEntity();
            BeanUtils.copyProperties(assemble,salesOrderDetailEntity);
            salesOrderDetailEntity.setId(SnowflakeWorker.nextId());
            salesOrderDetailEntity.setTenantSid(null);
            return salesOrderDetailEntity;
        }).collect(Collectors.toList());

        salesOrderDetailService.saveBatch(salesOrderDetailEntityList);

        return EAIUtil.buildEAIResult(new HashMap<>());
    }
}

==> v1.0.0.1001.tar.gz: athena-opt-demo/demo-athenaopt_backend/develop/src/main/java/com/digiwin/athena/app/service/order/SalesOrderDetailCreateEAIService.java <==
package com.digiwin.athena.app.service.order;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.digiwin.app.service.DWEAIResult;
import com.digiwin.athena.app.infra.dto.order.SalesOrderDetailDTO;
import com.digiwin.athena.app.infra.entity.SalesOrderDetailEntity;
import com.digiwin.athena.app.infra.service.SalesOrderDetailService;
import com.digiwin.athena.opt.common.eai.EAIRequest;
import com.digiwin.athena.opt.common.eai.EAIUtil;
import com.digiwin.athena.opt.common.eai.service.AbsEAIService;
import com.digiwin.athena.opt.common.generator.SnowflakeWorker;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author CR-7
 * create: 2023-04-27 15:35
 * Description:
 */
@Log4j2
@Service
public class SalesOrderDetailCreateEAIService extends AbsEAIService {

    @Resource
    SalesOrderDetailService salesOrderDetailService;


    @Override
    public String getServiceName() {
        return SalesOrderDetailUtil.DEMO_SO_ITEM_INFO_CREATE;
    }

    @Override
    public DWEAIResult execute(Map<String, String> headers, String messageBody) throws Exception {
        // 入参反序列化
        EAIRequest request = new EAIRequest(messageBody);
        List<SalesOrderDetailDTO> salesOrderDetailDTOList = request.getObject("sales_order_detail", new TypeReference<List<SalesOrderDetailDTO>>(){});

        List<SalesOrderDetailEntity> salesOrderDetailEntityList = salesOrderDetailDTOList.stream().map(assemble->{
            SalesOrderDetailEntity salesOrderDetailEntity = new SalesOrderDetailEntity();
            BeanUtils.copyProperties(assemble,salesOrderDetailEntity);
            salesOrderDetailEntity.setId(SnowflakeWorker.nextId());
            salesOrderDetailEntity.setTenantSid(1L);
            salesOrderDetailEntity.setStatus(1);
            return salesOrderDetailEntity;
        }).collect(Collectors.toList());

        salesOrderDetailService.saveBatch(salesOrderDetailEntityList);

        return EAIUtil.buildEAIResult(new JSONObject().fluentPut("sales_order_detail",salesOrderDetailEntityList));
    }
}
